package com.bbyb.operating.examination.config;

import com.alibaba.fastjson2.JSONObject;
import com.bbyb.operating.examination.utils.Result;
import lombok.extern.log4j.Log4j2;
import org.springframework.context.annotation.Configuration;
import org.springframework.validation.ObjectError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import java.util.stream.Collectors;

/**
 * @ClassName GlobalExceptionHand
 * @Description 描述
 * @Author WenSha.Wan
 * @Date 2024/1/11 11:01
 */
@RestControllerAdvice
@Configuration
@Log4j2
public class GlobalExceptionHand {

    @ExceptionHandler(value = MethodArgumentNotValidException.class)
    public Result<String> runtimeException(MethodArgumentNotValidException exception){
        return Result.error(
                JSONObject.toJSONString(
                        exception.getBindingResult().getAllErrors()
                                .stream()
                                .map(ObjectError::getDefaultMessage)
                                .collect(Collectors.toList())
                )

        );
    }

    @ExceptionHandler(value = IllegalArgumentException.class)
    public Result<String> illegalArgumentExceptionHandler(IllegalArgumentException exception){
        log.error("请求异常：[{}]", exception.getMessage(), exception);
        return Result.error(exception.getMessage());
    }

    @ExceptionHandler(value = RuntimeException.class)
    public Result<String> runtimeException(RuntimeException exception){
        log.error("请求异常：[{}]", exception.getMessage(), exception);
        return Result.error(exception.getMessage());
    }
    @ExceptionHandler(value = Exception.class)
    public Result<String> Exception(Exception exception){
        log.error("未知异常：[{}]", exception.getMessage(), exception);
        return Result.error(exception.getMessage());
    }

}
