package com.bbyb.operating.examination.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bbyb.operating.examination.mapper.RoleUserMapper;
import com.bbyb.operating.examination.mapper.UserMapper;
import com.bbyb.operating.examination.model.po.RoleUser;
import com.bbyb.operating.examination.model.po.User;
import com.bbyb.operating.examination.model.po.UserReq;
import com.bbyb.operating.examination.service.RoleUserService;
import com.bbyb.operating.examination.service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 账号服务
 * className: UserServiceImpl
 * datetime: 2023/2/10 14:29
 * author: lx
 */
@Service
public class UserServiceImpl extends ServiceImpl<UserMapper, User> implements UserService {

    @Autowired
    private UserMapper userMapper;
    @Autowired
    private RoleUserMapper roleUserMapper;
    @Autowired
    private RoleUserService roleUserService;


    @Override
    public String addUser(UserReq userReq) {
        if(userReq.getUserCode() == null || userReq.getUserCode().isEmpty()){
            throw new RuntimeException("用户编码不能为空");
        }
        User user = User.buildUser(userReq); // 确保buildUser方法名正确，之前是builUser
        user.setId(0);
        List<User> users = userMapper.selectAll();
        for (User user1 : users) {
            if(user1.getUserCode().equals(user.getUserCode())){
                throw new RuntimeException("用户已存在");
            }
        }
        int id = userMapper.insertUser(user);
        boolean userInserted = id > 0;

        if (userInserted) {
            RoleUser roleUser = new RoleUser();
            roleUser.setId(0);
            roleUser.setUserId(user.getId());
            roleUser.setRoleId(userReq.getRoleId());

            boolean roleUserInserted = roleUserMapper.insert(roleUser) > 0; // 插入角色用户关联信息并检查是否成功

            if (roleUserInserted) {
                return "保存用户信息成功";
            }
        }

        return "保存用户信息失败";
    }


    @Override
    public Boolean deleteUser(UserReq userReq) {
        if(userReq.getUserCode() != null){
            LambdaQueryWrapper<User> eq = new LambdaQueryWrapper<User>().eq(User::getUserCode, userReq.getUserCode());
            User user = userMapper.selectOne(eq);
            if(user != null){
                return true;
            }
            int i = userMapper.deleteByPrimaryKey(user.getId());
            if(i > 0){
                RoleUser roleUser = roleUserService.findRoleUser(userReq);
                if(roleUser != null){
                    int i1 = roleUserMapper.deleteByPrimaryKey(roleUser.getId());
                    if(i1 > 0){
                        return true;
                    }
                }
            }
        }
        return null;
    }


}
